@@ -81,7 +81,7 @@ cat > README.rst << "EOF"
 sqlmap
 ======
 
-|Build Status| |Python 2.6|2.7| |License| |Twitter|
+|Build Status| |Python 2.6|2.7|3.x| |License| |Twitter|
 
 sqlmap is an open source penetration testing tool that automates the
 process of detecting and exploiting SQL injection flaws and taking over
@@ -122,8 +122,8 @@ If you prefer fetching daily updates, you can download sqlmap by cloning the
     git clone --depth 1 https://github.com/sqlmapproject/sqlmap.git sqlmap-dev
 
 sqlmap works out of the box with
-`Python <http://www.python.org/download/>`__ version **2.6.x** and
-**2.7.x** on any platform.
+`Python <http://www.python.org/download/>`__ version **2.6**, **2.7** and
+**3.x** on any platform.
 
 Usage
 -----
@@ -165,7 +165,7 @@ Links
 
 .. |Build Status| image:: https://api.travis-ci.org/sqlmapproject/sqlmap.svg?branch=master
    :target: https://api.travis-ci.org/sqlmapproject/sqlmap
-.. |Python 2.6|2.7| image:: https://img.shields.io/badge/python-2.6|2.7-yellow.svg
+.. |Python 2.6|2.7|3.x| image:: https://img.shields.io/badge/python-2.6|2.7|3.x-yellow.svg
    :target: https://www.python.org/
 .. |License| image:: https://img.shields.io/badge/license-GPLv2-red.svg
    :target: https://raw.githubusercontent.com/sqlmapproject/sqlmap/master/LICENSE
