@@ -1,4 +1,4 @@
-#!/usr/bin/env python2
+#!/usr/bin/env python
 
 """
 Copyright (c) 2006-2019 sqlmap developers (http://sqlmap.org/)
@@ -7,13 +7,13 @@ See the file 'LICENSE' for copying permission
 
 import sqlite3
 
-from extra.safe2bin.safe2bin import safechardecode
 from lib.core.common import getSafeExString
 from lib.core.common import unsafeSQLIdentificatorNaming
 from lib.core.exception import SqlmapConnectionException
 from lib.core.exception import SqlmapGenericException
 from lib.core.exception import SqlmapValueException
 from lib.core.settings import UNICODE_ENCODING
+from lib.utils.safe2bin import safechardecode
 
 class Replication(object):
     """
@@ -32,7 +32,7 @@ class Replication(object):
             errMsg += "file '%s' ('%s')" % (self.filepath, getSafeExString(ex))
             raise SqlmapConnectionException(errMsg)
 
-    class DataType:
+    class DataType(object):
         """
         Using this class we define auxiliary objects
         used for representing sqlite data types.
@@ -47,7 +47,7 @@ class Replication(object):
         def __repr__(self):
             return "<DataType: %s>" % self
 
-    class Table:
+    class Table(object):
         """
         This class defines methods used to manipulate table objects.
         """
@@ -79,9 +79,9 @@ class Replication(object):
                 errMsg = "wrong number of columns used in replicating insert"
                 raise SqlmapValueException(errMsg)
 
-        def execute(self, sql, parameters=[]):
+        def execute(self, sql, parameters=None):
             try:
-                self.parent.cursor.execute(sql, parameters)
+                self.parent.cursor.execute(sql, parameters or [])
             except sqlite3.OperationalError as ex:
                 errMsg = "problem occurred ('%s') while accessing sqlite database " % getSafeExString(ex, UNICODE_ENCODING)
                 errMsg += "located at '%s'. Please make sure that " % self.parent.dbpath
