@@ -10,9 +10,6 @@ from lib.core.data import logger
 from plugins.generic.enumeration import Enumeration as GenericEnumeration
 
 class Enumeration(GenericEnumeration):
-    def __init__(self):
-        GenericEnumeration.__init__(self)
-
     def getHostname(self):
         warnMsg = "on PostgreSQL it is not possible to enumerate the hostname"
         logger.warn(warnMsg)
